.. image:: https://img.shields.io/github/license/YazdanRa/django-itelegram.svg
   :target: https://github.com/YazdanRa/django-itelegram/blob/master/LICENSE

.. image:: https://img.shields.io/badge/code%20style-black-000000.svg
    :target: https://github.com/psf/black

-------


Django iTelegram
=================

It's a library for building Telegram bot on Django with extra built-in options.
created from `django-telegrambot`_ with a lot of extra features


Compatibility
=============

- Python: **3.6**, **3.7**, **3.8**
- Django: **2.2**, **3.0**, **3.1**, **3.2**


Usage
=====

TODO :D


License
=======

`MIT`_

.. _`django-telegrambot`: https://pypi.org/project/django-telegrambot/
.. _`MIT`: https://github.com/YazdanRa/django-itelegram/blob/master/LICENSE
